@@ -53,7 +53,7 @@ class GmpV208Mixin(GvmProtocol):
         self,
         connection: GvmConnection,
         *,
-        transform: Optional[Callable[[str], Any]] = None
+        transform: Optional[Callable[[str], Any]] = None,
     ):
         super().__init__(connection, transform=transform)
 
@@ -68,7 +68,7 @@ class GmpV208Mixin(GvmProtocol):
         *,
         comment: Optional[str] = None,
         howto_install: Optional[str] = None,
-        howto_use: Optional[str] = None
+        howto_use: Optional[str] = None,
     ) -> None:
         # pylint: disable=unused-argument
         deprecation(
@@ -94,7 +94,7 @@ class GmpV208Mixin(GvmProtocol):
         agent_id: str,
         *,
         name: Optional[str] = None,
-        comment: Optional[str] = None
+        comment: Optional[str] = None,
     ) -> None:
         # pylint: disable=unused-argument
         deprecation(
@@ -147,7 +147,7 @@ class GmpV208Mixin(GvmProtocol):
         filter: Optional[str] = None,
         filter_id: Optional[str] = None,
         name: Optional[str] = None,
-        details: Optional[bool] = None
+        details: Optional[bool] = None,
     ) -> Any:
         """Request a list of security information
 
@@ -244,7 +244,7 @@ class GmpV208Mixin(GvmProtocol):
         reverse_lookup_only: Optional[bool] = None,
         reverse_lookup_unify: Optional[bool] = None,
         port_range: Optional[str] = None,
-        port_list_id: Optional[str] = None
+        port_list_id: Optional[str] = None,
     ) -> Any:
         """Create a new target
 
