@@ -23,6 +23,7 @@ from gvm.errors import InvalidArgument
 
 
 from gvm.protocols.gmpv208.types import (
+    AggregateStatistic,
     AlertCondition,
     AlertEvent,
     AlertMethod,
@@ -40,9 +41,11 @@ from gvm.protocols.gmpv208.types import (
     ScannerType,
     SnmpAuthAlgorithm,
     SnmpPrivacyAlgorithm,
+    SortOrder,
     TicketStatus,
     TimeUnit,
     UserAuthType,
+    get_aggregate_statistic_from_string,
     get_alert_condition_from_string,
     get_alert_event_from_string,
     get_alert_method_from_string,
@@ -60,6 +63,7 @@ from gvm.protocols.gmpv208.types import (
     get_scanner_type_from_string,
     get_snmp_auth_algorithm_from_string,
     get_snmp_privacy_algorithm_from_string,
+    get_sort_order_from_string,
     get_ticket_status_from_string,
     get_time_unit_from_string,
     get_user_auth_type_from_string,
@@ -67,6 +71,7 @@ from gvm.protocols.gmpv208.types import (
 
 
 __all__ = [
+    "AggregateStatistic",
     "AlertCondition",
     "AlertEvent",
     "AlertMethod",
@@ -85,9 +90,11 @@ __all__ = [
     "SeverityLevel",
     "SnmpAuthAlgorithm",
     "SnmpPrivacyAlgorithm",
+    "SortOrder",
     "TicketStatus",
     "TimeUnit",
     "UserAuthType",
+    "get_aggregate_statistic_from_string",
     "get_alert_condition_from_string",
     "get_alert_event_from_string",
     "get_alert_method_from_string",
@@ -106,6 +113,7 @@ __all__ = [
     "get_severity_level_from_string",
     "get_snmp_auth_algorithm_from_string",
     "get_snmp_privacy_algorithm_from_string",
+    "get_sort_order_from_string",
     "get_ticket_status_from_string",
     "get_time_unit_from_string",
     "get_user_auth_type_from_string",
