@@ -47,7 +47,7 @@ class Gmp(GmpV9Mixin, GmpV8Mixin, GmpV7Mixin):
         self,
         connection: GvmConnection,
         *,
-        transform: Optional[Callable[[str], Any]] = None
+        transform: Optional[Callable[[str], Any]] = None,
     ):
         super().__init__(connection, transform=transform)
 
