@@ -20,7 +20,7 @@ Module for transforming responses
 """
 from lxml import etree
 
-from .errors import GvmError
+from .errors import GvmError, GvmServerError, GvmResponseError
 from .xml import create_parser
 
 
@@ -43,12 +43,16 @@ def _check_command_status(root: etree.Element):
     status = root.get("status")
 
     if status is None:
-        raise GvmError("No status in response.", root)
+        raise GvmServerError("No status in response.", root)
 
-    if status[0] != "2":
-        status_text = root.get("status_text")
-
-        raise GvmError("Error in response. {0}".format(status_text), root)
+    if status[0] == "4":
+        raise GvmResponseError(status=status, message=root.get("status_text"))
+    elif status[0] == "5":
+        raise GvmServerError(status=status, message=root.get("status_text"))
+    elif status[0] != "2":
+        raise GvmError(
+            "Error in response. {0}".format(root.get("status_text")), root
+        )
 
 
 class CheckCommandTransform(EtreeTransform):
