@@ -39,6 +39,20 @@ class GmpGetPreferenceTestCase:
         with self.assertRaises(RequiredArgument):
             self.gmp.get_preference('')
 
+    def test_get_preference_with_nvt_oid(self):
+        self.gmp.get_preference(name='foo', nvt_oid='oid')
+
+        self.connection.send.has_been_called_with(
+            '<get_preferences preference="foo" nvt_oid="oid"/>'
+        )
+
+    def test_get_preference_with_config_id(self):
+        self.gmp.get_preference(name='foo', config_id='c1')
+
+        self.connection.send.has_been_called_with(
+            '<get_preferences preference="foo" config_id="c1"/>'
+        )
+
 
 if __name__ == '__main__':
     unittest.main()
