@@ -37,6 +37,12 @@ class Gmpv8CloneConfigTestCase(GmpCloneConfigTestCase, Gmpv8TestCase):
     pass
 
 
+class Gmpv8CloneReportFormatTestCase(
+    GmpCloneReportFormatTestCase, Gmpv8TestCase
+):
+    pass
+
+
 class Gmpv8CloneCredentialTestCase(GmpCloneCredentialTestCase, Gmpv8TestCase):
 
     pass
@@ -484,6 +490,12 @@ class Gmpv8ImportConfigTestCase(GmpImportConfigTestCase, Gmpv8TestCase):
     pass
 
 
+class Gmpv8ImportReportFormatTestCase(
+    GmpImportReportFormatTestCase, Gmpv8TestCase
+):
+    pass
+
+
 class Gmpv8ImportReportTestCase(GmpImportReportTestCase, Gmpv8TestCase):
     pass
 
@@ -560,12 +572,6 @@ class Gmpv8ModifyPortListTestCase(GmpModifyPortListTestCase, Gmpv8TestCase):
     pass
 
 
-class Gmpv8ModifyReportFormatTestCase(
-    GmpModifyReportFormatTestCase, Gmpv8TestCase
-):
-    pass
-
-
 class Gmpv8ModifyRoleTestCase(GmpModifyRoleTestCase, Gmpv8TestCase):
     pass
 
