@@ -27,7 +27,7 @@ class GmpGetTlsCertificateTestCase:
 
         self.connection.send.has_been_called_with(
             '<get_tls_certificates tls_certificate_id="t1" '
-            'include_certificate_data="1"/>'
+            'include_certificate_data="1" details="1"/>'
         )
 
     def test_fail_without_tls_certificate_id(self):
