@@ -20,7 +20,7 @@ import unittest
 
 from lxml import etree
 
-from gvm.errors import GvmError
+from gvm.errors import GvmError, GvmResponseError, GvmServerError
 from gvm.transforms import CheckCommandTransform
 
 
@@ -31,7 +31,19 @@ class CheckCommandTransformTestCase(unittest.TestCase):
         with self.assertRaises(GvmError):
             transform('<foo/')
 
-    def test_no_success_status_transform(self):
+    def test_no_success_300status_transform(self):
+        transform = CheckCommandTransform()
+
+        root = etree.Element('foo_response')
+        root.set('status', '300')
+        root.set('status_text', 'Foo error')
+
+        response = etree.tostring(root).decode('utf-8')
+
+        with self.assertRaises(GvmError):
+            transform(response)
+
+    def test_no_success_400status_transform(self):
         transform = CheckCommandTransform()
 
         root = etree.Element('foo_response')
@@ -40,7 +52,19 @@ class CheckCommandTransformTestCase(unittest.TestCase):
 
         response = etree.tostring(root).decode('utf-8')
 
-        with self.assertRaises(GvmError):
+        with self.assertRaises(GvmResponseError):
+            transform(response)
+
+    def test_no_success_500status_transform(self):
+        transform = CheckCommandTransform()
+
+        root = etree.Element('foo_response')
+        root.set('status', '500')
+        root.set('status_text', 'Foo error')
+
+        response = etree.tostring(root).decode('utf-8')
+
+        with self.assertRaises(GvmServerError):
             transform(response)
 
     def test_success_response(self):
